@@ -37,6 +37,7 @@
 #include "ide-device.h"
 #include "ide-foundry-compat.h"
 #include "ide-pipeline.h"
+#include "ide-run-manager.h"
 #include "ide-runtime-manager.h"
 #include "ide-runtime-private.h"
 #include "ide-runtime.h"
@@ -527,6 +528,10 @@ ide_build_manager_device_get_info_cb (GObject      *object,
       IDE_EXIT;
     }
 
+  IDE_TRACE_MSG (" Device Kind = %d", ide_device_info_get_kind (info));
+  IDE_TRACE_MSG (" Device Triplet = %s",
+                 ide_triplet_get_full_name (ide_device_info_get_host_triplet (info)));
+
   _ide_pipeline_check_toolchain (pipeline, info);
 
   _ide_runtime_manager_prepare_async (runtime_manager,
@@ -544,6 +549,7 @@ ide_build_manager_invalidate_pipeline (IdeBuildManager *self)
   g_autoptr(IdeTask) task = NULL;
   IdeConfigManager *config_manager;
   IdeDeviceManager *device_manager;
+  IdeRunManager *run_manager;
   IdeConfig *config;
   IdeContext *context;
   IdeDevice *device;
@@ -569,6 +575,12 @@ ide_build_manager_invalidate_pipeline (IdeBuildManager *self)
       g_signal_emit (self, signals [BUILD_FAILED], 0, self->pipeline);
     }
 
+  /*
+   * Clear any cached build targets from the run manager.
+   */
+  run_manager = ide_run_manager_from_context (context);
+  ide_run_manager_set_build_target (run_manager, NULL);
+
   /*
    * Cancel and clear our previous pipeline and associated components
    * as they are not invalide.
