@@ -912,7 +912,7 @@ ide_run_manager_set_build_target (IdeRunManager  *self,
                                   IdeBuildTarget *build_target)
 {
   g_return_if_fail (IDE_IS_RUN_MANAGER (self));
-  g_return_if_fail (IDE_IS_BUILD_TARGET (build_target));
+  g_return_if_fail (!build_target || IDE_IS_BUILD_TARGET (build_target));
 
   if (build_target == self->build_target)
     return;
@@ -1020,8 +1020,8 @@ ide_run_manager_provider_get_targets_cb (GObject      *object,
                                      0,
                                      (GDestroyNotify)ide_object_unref_and_destroy);
   ide_task_return_pointer (task,
-                           g_steal_pointer (&first),
-                           (GDestroyNotify)ide_object_unref_and_destroy);
+                           IDE_OBJECT (g_steal_pointer (&first)),
+                           ide_object_unref_and_destroy);
 
   IDE_EXIT;
 }
