@@ -203,6 +203,7 @@ stack_notify_visible_child_cb (IdeGreeterWorkspace *self,
                                GtkStack            *stack)
 {
   g_autofree gchar *title = NULL;
+  g_autofree gchar *full_title = NULL;
   GtkWidget *visible_child;
   gboolean sections;
 
@@ -212,9 +213,13 @@ stack_notify_visible_child_cb (IdeGreeterWorkspace *self,
   visible_child = gtk_stack_get_visible_child (stack);
 
   if (DZL_IS_DOCK_ITEM (visible_child))
-    title = dzl_dock_item_get_title (DZL_DOCK_ITEM (visible_child));
+    {
+      if ((title = dzl_dock_item_get_title (DZL_DOCK_ITEM (visible_child))))
+        full_title = g_strdup_printf (_("Builder — %s"), title);
+    }
 
   gtk_label_set_label (self->title, title);
+  gtk_window_set_title (GTK_WINDOW (self), full_title);
 
   sections = ide_str_equal0 ("sections", gtk_stack_get_visible_child_name (stack));
 
@@ -253,12 +258,11 @@ ide_greeter_workspace_addin_removed_cb (PeasExtensionSet *set,
                                         gpointer          user_data)
 {
   IdeGreeterSection *section = (IdeGreeterSection *)exten;
-  IdeGreeterWorkspace *self = user_data;
 
   g_assert (PEAS_IS_EXTENSION_SET (set));
   g_assert (plugin_info != NULL);
   g_assert (IDE_IS_GREETER_SECTION (section));
-  g_assert (IDE_IS_GREETER_WORKSPACE (self));
+  g_assert (IDE_IS_GREETER_WORKSPACE (user_data));
 
   gtk_widget_destroy (GTK_WIDGET (section));
 }
@@ -335,7 +339,7 @@ ide_greeter_workspace_open_project_cb (GObject      *object,
                                 G_CALLBACK (gtk_widget_destroy),
                                 workbench);
 
-      gtk_window_present (GTK_WINDOW (dialog));
+      ide_gtk_window_present (GTK_WINDOW (dialog));
 
       ide_greeter_workspace_end (self);
     }
@@ -526,7 +530,7 @@ ide_greeter_workspace_purge_selected_rows (GSimpleAction *action,
                          g_object_ref (self),
                          (GClosureNotify)g_object_unref,
                          G_CONNECT_SWAPPED);
-  gtk_window_present (GTK_WINDOW (dialog));
+  ide_gtk_window_present (GTK_WINDOW (dialog));
 }
 
 static void
