@@ -52,10 +52,12 @@ struct _IdeProjectInfo
   GFile      *directory;
   GFile      *file;
   gchar      *build_system_name;
+  gchar      *build_system_hint;
   gchar      *name;
   gchar      *description;
   gchar     **languages;
   gchar      *vcs_uri;
+  GIcon      *icon;
 
   gint        priority;
 
@@ -66,11 +68,14 @@ G_DEFINE_TYPE (IdeProjectInfo, ide_project_info, G_TYPE_OBJECT)
 
 enum {
   PROP_0,
+  PROP_BUILD_SYSTEM_HINT,
   PROP_BUILD_SYSTEM_NAME,
   PROP_DESCRIPTION,
   PROP_DIRECTORY,
   PROP_DOAP,
   PROP_FILE,
+  PROP_ICON,
+  PROP_ICON_NAME,
   PROP_ID,
   PROP_IS_RECENT,
   PROP_LANGUAGES,
@@ -131,9 +136,12 @@ ide_project_info_set_languages (IdeProjectInfo  *self,
 {
   g_return_if_fail (IDE_IS_PROJECT_INFO (self));
 
-  g_strfreev (self->languages);
-  self->languages = g_strdupv (languages);
-  g_object_notify_by_pspec (G_OBJECT (self), properties [PROP_LANGUAGES]);
+  if (languages != self->languages)
+    {
+      g_strfreev (self->languages);
+      self->languages = g_strdupv (languages);
+      g_object_notify_by_pspec (G_OBJECT (self), properties [PROP_LANGUAGES]);
+    }
 }
 
 gint
@@ -211,6 +219,28 @@ ide_project_info_get_last_modified_at (IdeProjectInfo *self)
   return self->last_modified_at;
 }
 
+const gchar *
+ide_project_info_get_build_system_hint (IdeProjectInfo *self)
+{
+  g_return_val_if_fail (IDE_IS_PROJECT_INFO (self), NULL);
+
+  return self->build_system_hint;
+}
+
+void
+ide_project_info_set_build_system_hint (IdeProjectInfo *self,
+                                        const gchar    *build_system_hint)
+{
+  g_return_if_fail (IDE_IS_PROJECT_INFO (self));
+
+  if (!ide_str_equal0 (self->build_system_hint, build_system_hint))
+    {
+      g_free (self->build_system_hint);
+      self->build_system_hint = g_strdup (build_system_hint);
+      g_object_notify_by_pspec (G_OBJECT (self), properties [PROP_BUILD_SYSTEM_HINT]);
+    }
+}
+
 const gchar *
 ide_project_info_get_build_system_name (IdeProjectInfo *self)
 {
@@ -343,12 +373,15 @@ ide_project_info_finalize (GObject *object)
 
   g_clear_pointer (&self->id, g_free);
   g_clear_pointer (&self->last_modified_at, g_date_time_unref);
+  g_clear_pointer (&self->build_system_hint, g_free);
   g_clear_pointer (&self->build_system_name, g_free);
   g_clear_pointer (&self->description, g_free);
   g_clear_pointer (&self->languages, g_strfreev);
+  g_clear_pointer (&self->vcs_uri, g_free);
   g_clear_pointer (&self->name, g_free);
   g_clear_object (&self->directory);
   g_clear_object (&self->file);
+  g_clear_object (&self->icon);
 
   G_OBJECT_CLASS (ide_project_info_parent_class)->finalize (object);
 }
@@ -363,6 +396,10 @@ ide_project_info_get_property (GObject    *object,
 
   switch (prop_id)
     {
+    case PROP_BUILD_SYSTEM_HINT:
+      g_value_set_string (value, ide_project_info_get_build_system_hint (self));
+      break;
+
     case PROP_BUILD_SYSTEM_NAME:
       g_value_set_string (value, ide_project_info_get_build_system_name (self));
       break;
@@ -383,6 +420,10 @@ ide_project_info_get_property (GObject    *object,
       g_value_set_object (value, ide_project_info_get_file (self));
       break;
 
+    case PROP_ICON:
+      g_value_set_object (value, ide_project_info_get_icon (self));
+      break;
+
     case PROP_ID:
       g_value_set_string (value, ide_project_info_get_id (self));
       break;
@@ -426,6 +467,10 @@ ide_project_info_set_property (GObject      *object,
 
   switch (prop_id)
     {
+    case PROP_BUILD_SYSTEM_HINT:
+      ide_project_info_set_build_system_hint (self, g_value_get_string (value));
+      break;
+
     case PROP_BUILD_SYSTEM_NAME:
       ide_project_info_set_build_system_name (self, g_value_get_string (value));
       break;
@@ -446,6 +491,14 @@ ide_project_info_set_property (GObject      *object,
       ide_project_info_set_file (self, g_value_get_object (value));
       break;
 
+    case PROP_ICON:
+      ide_project_info_set_icon (self, g_value_get_object (value));
+      break;
+
+    case PROP_ICON_NAME:
+      ide_project_info_set_icon_name (self, g_value_get_string (value));
+      break;
+
     case PROP_ID:
       ide_project_info_set_id (self, g_value_get_string (value));
       break;
@@ -488,6 +541,13 @@ ide_project_info_class_init (IdeProjectInfoClass *klass)
   object_class->get_property = ide_project_info_get_property;
   object_class->set_property = ide_project_info_set_property;
 
+  properties [PROP_BUILD_SYSTEM_HINT] =
+    g_param_spec_string ("build-system-hint",
+                         "Build System hint",
+                         "Build System hint",
+                         NULL,
+                         (G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_STATIC_STRINGS));
+
   properties [PROP_BUILD_SYSTEM_NAME] =
     g_param_spec_string ("build-system-name",
                          "Build System name",
@@ -502,6 +562,20 @@ ide_project_info_class_init (IdeProjectInfoClass *klass)
                          NULL,
                          (G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_STATIC_STRINGS));
 
+  properties [PROP_ICON] =
+    g_param_spec_object ("icon",
+                         "Icon",
+                         "The icon for the project",
+                         G_TYPE_ICON,
+                         (G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_STATIC_STRINGS));
+
+  properties [PROP_ICON_NAME] =
+    g_param_spec_string ("icon-name",
+                         "Icon Name",
+                         "The icon-name for the project",
+                         NULL,
+                         (G_PARAM_WRITABLE | G_PARAM_STATIC_STRINGS));
+
   properties [PROP_ID] =
     g_param_spec_string ("id",
                          "Id",
@@ -720,8 +794,13 @@ ide_project_info_get_id (IdeProjectInfo *self)
 
   if (!self->id && self->file)
     {
-      g_autoptr(GFile) parent = g_file_get_parent (self->file);
-      self->id = g_file_get_basename (parent);
+      if (g_file_query_file_type (self->file, 0, NULL) == G_FILE_TYPE_DIRECTORY)
+        self->id = g_file_get_basename (self->file);
+      else
+        {
+          g_autoptr(GFile) parent = g_file_get_parent (self->file);
+          self->id = g_file_get_basename (parent);
+        }
     }
 
   if (!self->id && self->doap)
@@ -758,3 +837,45 @@ ide_project_info_set_id (IdeProjectInfo *self,
       g_object_notify_by_pspec (G_OBJECT (self), properties [PROP_ID]);
     }
 }
+
+/**
+ * ide_project_info_get_icon:
+ * @self: a #IdeProjectInfo
+ *
+ * Gets the #IdeProjectInfo:icon property.
+ *
+ * Returns: (transfer none) (nullable): a #GIcon or %NULL
+ *
+ * Since: 3.32
+ */
+GIcon *
+ide_project_info_get_icon (IdeProjectInfo *self)
+{
+  g_return_val_if_fail (IDE_IS_PROJECT_INFO (self), NULL);
+
+  return self->icon;
+}
+
+void
+ide_project_info_set_icon (IdeProjectInfo *self,
+                           GIcon          *icon)
+{
+  g_return_if_fail (IDE_IS_PROJECT_INFO (self));
+  g_return_if_fail (!icon || G_IS_ICON (icon));
+
+  if (g_set_object (&self->icon, icon))
+    g_object_notify_by_pspec (G_OBJECT (self), properties [PROP_ICON]);
+}
+
+void
+ide_project_info_set_icon_name (IdeProjectInfo *self,
+                                const gchar    *icon_name)
+{
+  g_autoptr(GIcon) icon = NULL;
+
+  g_return_if_fail (IDE_IS_PROJECT_INFO (self));
+
+  if (icon_name != NULL)
+    icon = g_themed_icon_new (icon_name);
+  ide_project_info_set_icon (self, icon);
+}
