@@ -42,6 +42,7 @@ struct _GbpBuilduiOmniBarSection
   GtkLabel       *popover_build_message;
   GtkLabel       *popover_build_result_label;
   GtkLabel       *popover_config_label;
+  GtkLabel       *popover_device_label;
   GtkLabel       *popover_errors_label;
   GtkLabel       *popover_last_build_time_label;
   GtkLabel       *popover_project_label;
@@ -74,7 +75,11 @@ gbp_buildui_omni_bar_section_notify_pipeline (GbpBuilduiOmniBarSection *self,
                                               GParamSpec               *pspec,
                                               IdeBuildManager          *build_manager)
 {
-  IdeBuildPipeline *pipeline;
+  IdePipeline *pipeline;
+  const gchar *device_name = NULL;
+  const gchar *runtime_name = NULL;
+  const gchar *config_id = "";
+  const gchar *display_name = NULL;
 
   g_assert (IDE_IS_MAIN_THREAD ());
   g_assert (GBP_IS_BUILDUI_OMNI_BAR_SECTION (self));
@@ -82,24 +87,26 @@ gbp_buildui_omni_bar_section_notify_pipeline (GbpBuilduiOmniBarSection *self,
 
   if ((pipeline = ide_build_manager_get_pipeline (build_manager)))
     {
-      IdeConfiguration *config = ide_build_pipeline_get_configuration (pipeline);
-      const gchar *config_id = ide_configuration_get_id (config);
-      const gchar *display_name = ide_configuration_get_display_name (config);
-      IdeRuntime *runtime = ide_configuration_get_runtime (config);
-      const gchar *name = NULL;
+      IdeConfig *config = ide_pipeline_get_config (pipeline);
+      IdeRuntime *runtime = ide_config_get_runtime (config);
+      IdeDevice *device = ide_pipeline_get_device (pipeline);
 
-      gtk_label_set_label (self->popover_config_label, display_name);
+      config_id = ide_config_get_id (config);
+      display_name = ide_config_get_display_name (config);
 
       if (runtime != NULL)
-        name = ide_runtime_get_display_name (runtime);
+        runtime_name = ide_runtime_get_display_name (runtime);
+      if (runtime_name == NULL)
+        runtime_name = ide_runtime_get_id (runtime);
 
-      if (name == NULL)
-        name = ide_runtime_get_id (runtime);
-
-      gtk_label_set_label (self->popover_runtime_label, name);
-
-      gtk_actionable_set_action_target (GTK_ACTIONABLE (self->configure_button), "s", config_id);
+      if (device != NULL)
+        device_name = ide_device_get_display_name (device);
     }
+
+  gtk_label_set_label (self->popover_config_label, display_name);
+  gtk_label_set_label (self->popover_device_label, device_name);
+  gtk_label_set_label (self->popover_runtime_label, runtime_name);
+  gtk_actionable_set_action_target (GTK_ACTIONABLE (self->configure_button), "s", config_id);
 }
 
 static void
@@ -172,14 +179,14 @@ gbp_buildui_omni_bar_section_notify_message (GbpBuilduiOmniBarSection *self,
 
 static void
 gbp_buildui_omni_bar_section_build_started (GbpBuilduiOmniBarSection *self,
-                                            IdeBuildPipeline         *pipeline,
+                                            IdePipeline         *pipeline,
                                             IdeBuildManager          *build_manager)
 {
   IDE_ENTRY;
 
   g_assert (IDE_IS_MAIN_THREAD ());
   g_assert (GBP_IS_BUILDUI_OMNI_BAR_SECTION (self));
-  g_assert (IDE_IS_BUILD_PIPELINE (pipeline));
+  g_assert (IDE_IS_PIPELINE (pipeline));
   g_assert (IDE_IS_BUILD_MANAGER (build_manager));
 
   gtk_revealer_set_reveal_child (self->popover_details_revealer, TRUE);
@@ -192,14 +199,14 @@ gbp_buildui_omni_bar_section_build_started (GbpBuilduiOmniBarSection *self,
 
 static void
 gbp_buildui_omni_bar_section_build_failed (GbpBuilduiOmniBarSection *self,
-                                           IdeBuildPipeline         *pipeline,
+                                           IdePipeline         *pipeline,
                                            IdeBuildManager          *build_manager)
 {
   IDE_ENTRY;
 
   g_assert (IDE_IS_MAIN_THREAD ());
   g_assert (GBP_IS_BUILDUI_OMNI_BAR_SECTION (self));
-  g_assert (IDE_IS_BUILD_PIPELINE (pipeline));
+  g_assert (IDE_IS_PIPELINE (pipeline));
   g_assert (IDE_IS_BUILD_MANAGER (build_manager));
 
   gtk_label_set_label (self->popover_build_result_label, _("Failed"));
@@ -210,14 +217,14 @@ gbp_buildui_omni_bar_section_build_failed (GbpBuilduiOmniBarSection *self,
 
 static void
 gbp_buildui_omni_bar_section_build_finished (GbpBuilduiOmniBarSection *self,
-                                             IdeBuildPipeline         *pipeline,
+                                             IdePipeline         *pipeline,
                                              IdeBuildManager          *build_manager)
 {
   IDE_ENTRY;
 
   g_assert (IDE_IS_MAIN_THREAD ());
   g_assert (GBP_IS_BUILDUI_OMNI_BAR_SECTION (self));
-  g_assert (IDE_IS_BUILD_PIPELINE (pipeline));
+  g_assert (IDE_IS_PIPELINE (pipeline));
   g_assert (IDE_IS_BUILD_MANAGER (build_manager));
 
   gtk_label_set_label (self->popover_build_result_label, _("Success"));
@@ -288,6 +295,7 @@ gbp_buildui_omni_bar_section_class_init (GbpBuilduiOmniBarSectionClass *klass)
   gtk_widget_class_bind_template_child (widget_class, GbpBuilduiOmniBarSection, popover_build_result_label);
   gtk_widget_class_bind_template_child (widget_class, GbpBuilduiOmniBarSection, popover_config_label);
   gtk_widget_class_bind_template_child (widget_class, GbpBuilduiOmniBarSection, popover_details_revealer);
+  gtk_widget_class_bind_template_child (widget_class, GbpBuilduiOmniBarSection, popover_device_label);
   gtk_widget_class_bind_template_child (widget_class, GbpBuilduiOmniBarSection, popover_errors_label);
   gtk_widget_class_bind_template_child (widget_class, GbpBuilduiOmniBarSection, popover_last_build_time_label);
   gtk_widget_class_bind_template_child (widget_class, GbpBuilduiOmniBarSection, popover_project_label);
