@@ -35,10 +35,10 @@ struct _GbpCMakePipelineAddin
 
 static const gchar *ninja_names[] = { "ninja-build", "ninja" };
 
-static void build_pipeline_addin_iface_init (IdeBuildPipelineAddinInterface *iface);
+static void pipeline_addin_iface_init (IdePipelineAddinInterface *iface);
 
 G_DEFINE_TYPE_WITH_CODE (GbpCMakePipelineAddin, gbp_cmake_pipeline_addin, IDE_TYPE_OBJECT,
-                         G_IMPLEMENT_INTERFACE (IDE_TYPE_BUILD_PIPELINE_ADDIN, build_pipeline_addin_iface_init))
+                         G_IMPLEMENT_INTERFACE (IDE_TYPE_PIPELINE_ADDIN, pipeline_addin_iface_init))
 
 static void
 gbp_cmake_pipeline_addin_class_init (GbpCMakePipelineAddinClass *klass)
@@ -51,31 +51,31 @@ gbp_cmake_pipeline_addin_init (GbpCMakePipelineAddin *self)
 }
 
 static void
-gbp_cmake_pipeline_addin_stage_query_cb (IdeBuildStage    *stage,
-                                         IdeBuildPipeline *pipeline,
+gbp_cmake_pipeline_addin_stage_query_cb (IdePipelineStage    *stage,
+                                         IdePipeline *pipeline,
                                          GPtrArray        *targets,
                                          GCancellable     *cancellable)
 {
-  g_assert (IDE_IS_BUILD_STAGE (stage));
-  g_assert (IDE_IS_BUILD_PIPELINE (pipeline));
+  g_assert (IDE_IS_PIPELINE_STAGE (stage));
+  g_assert (IDE_IS_PIPELINE (pipeline));
   g_assert (!cancellable || G_IS_CANCELLABLE (cancellable));
 
   /* Defer to ninja to determine completed status */
-  ide_build_stage_set_completed (stage, FALSE);
+  ide_pipeline_stage_set_completed (stage, FALSE);
 }
 
 static void
-gbp_cmake_pipeline_addin_load (IdeBuildPipelineAddin *addin,
-                               IdeBuildPipeline      *pipeline)
+gbp_cmake_pipeline_addin_load (IdePipelineAddin *addin,
+                               IdePipeline      *pipeline)
 {
   GbpCMakePipelineAddin *self = (GbpCMakePipelineAddin *)addin;
   g_autoptr(IdeSubprocessLauncher) configure_launcher = NULL;
   g_autoptr(IdeSubprocessLauncher) build_launcher = NULL;
   g_autoptr(IdeSubprocessLauncher) install_launcher = NULL;
   g_autoptr(IdeSubprocessLauncher) clean_launcher = NULL;
-  g_autoptr(IdeBuildStage) configure_stage = NULL;
-  g_autoptr(IdeBuildStage) build_stage = NULL;
-  g_autoptr(IdeBuildStage) install_stage = NULL;
+  g_autoptr(IdePipelineStage) configure_stage = NULL;
+  g_autoptr(IdePipelineStage) build_stage = NULL;
+  g_autoptr(IdePipelineStage) install_stage = NULL;
   g_autoptr(GError) error = NULL;
   g_autofree gchar *prefix_option = NULL;
   g_autofree gchar *build_ninja = NULL;
@@ -84,7 +84,7 @@ gbp_cmake_pipeline_addin_load (IdeBuildPipelineAddin *addin,
   g_autofree gchar *project_file_name = NULL;
   g_autofree gchar *srcdir = NULL;
   IdeBuildSystem *build_system;
-  IdeConfiguration *configuration;
+  IdeConfig *configuration;
   IdeContext *context;
   IdeRuntime *runtime;
   IdeToolchain *toolchain;
@@ -98,7 +98,7 @@ gbp_cmake_pipeline_addin_load (IdeBuildPipelineAddin *addin,
   IDE_ENTRY;
 
   g_assert (GBP_IS_CMAKE_PIPELINE_ADDIN (self));
-  g_assert (IDE_IS_BUILD_PIPELINE (pipeline));
+  g_assert (IDE_IS_PIPELINE (pipeline));
 
   context = ide_object_get_context (IDE_OBJECT (self));
 
@@ -109,20 +109,20 @@ gbp_cmake_pipeline_addin_load (IdeBuildPipelineAddin *addin,
   g_object_get (build_system, "project-file", &project_file, NULL);
   project_file_name = g_file_get_basename (project_file);
 
-  configuration = ide_build_pipeline_get_configuration (pipeline);
-  runtime = ide_build_pipeline_get_runtime (pipeline);
-  toolchain = ide_build_pipeline_get_toolchain (pipeline);
+  configuration = ide_pipeline_get_config (pipeline);
+  runtime = ide_pipeline_get_runtime (pipeline);
+  toolchain = ide_pipeline_get_toolchain (pipeline);
 
   if (g_strcmp0 (project_file_name, "CMakeLists.txt") == 0)
     srcdir = g_dirname (g_file_peek_path (project_file));
   else
-    srcdir = g_strdup (ide_build_pipeline_get_srcdir (pipeline));
+    srcdir = g_strdup (ide_pipeline_get_srcdir (pipeline));
 
-  g_assert (IDE_IS_CONFIGURATION (configuration));
+  g_assert (IDE_IS_CONFIG (configuration));
   g_assert (IDE_IS_RUNTIME (runtime));
   g_assert (srcdir != NULL);
 
-  if (!(cmake = ide_configuration_getenv (configuration, "CMAKE")))
+  if (!(cmake = ide_config_getenv (configuration, "CMAKE")))
     cmake = "cmake";
 
   for (guint i = 0; i < G_N_ELEMENTS (ninja_names); i++)
@@ -140,15 +140,15 @@ gbp_cmake_pipeline_addin_load (IdeBuildPipelineAddin *addin,
       IDE_EXIT;
     }
 
-  if (NULL == (configure_launcher = ide_build_pipeline_create_launcher (pipeline, &error)) ||
-      NULL == (build_launcher = ide_build_pipeline_create_launcher (pipeline, &error)) ||
-      NULL == (clean_launcher = ide_build_pipeline_create_launcher (pipeline, &error)) ||
-      NULL == (install_launcher = ide_build_pipeline_create_launcher (pipeline, &error)))
+  if (NULL == (configure_launcher = ide_pipeline_create_launcher (pipeline, &error)) ||
+      NULL == (build_launcher = ide_pipeline_create_launcher (pipeline, &error)) ||
+      NULL == (clean_launcher = ide_pipeline_create_launcher (pipeline, &error)) ||
+      NULL == (install_launcher = ide_pipeline_create_launcher (pipeline, &error)))
     IDE_GOTO (failure);
 
-  prefix = ide_configuration_get_prefix (configuration);
-  config_opts = ide_configuration_get_config_opts (configuration);
-  parallelism = ide_configuration_get_parallelism (configuration);
+  prefix = ide_config_get_prefix (configuration);
+  config_opts = ide_config_get_config_opts (configuration);
+  parallelism = ide_config_get_parallelism (configuration);
 
   /* Create the toolchain file if required */
   if (GBP_IS_CMAKE_TOOLCHAIN (toolchain))
@@ -156,11 +156,11 @@ gbp_cmake_pipeline_addin_load (IdeBuildPipelineAddin *addin,
   else if (g_strcmp0 (ide_toolchain_get_id (toolchain), "default") != 0)
     {
       GbpCMakeBuildStageCrossFile *cross_file_stage;
-      cross_file_stage = gbp_cmake_build_stage_cross_file_new (context, toolchain);
+      cross_file_stage = gbp_cmake_build_stage_cross_file_new (toolchain);
       crossbuild_file = gbp_cmake_build_stage_cross_file_get_path (cross_file_stage, pipeline);
 
-      id = ide_build_pipeline_attach (pipeline, IDE_BUILD_PHASE_PREPARE, 0, IDE_BUILD_STAGE (cross_file_stage));
-      ide_build_pipeline_addin_track (addin, id);
+      id = ide_pipeline_attach (pipeline, IDE_PIPELINE_PHASE_PREPARE, 0, IDE_PIPELINE_STAGE (cross_file_stage));
+      ide_pipeline_addin_track (addin, id);
     }
 
   /* Setup our configure stage. */
@@ -193,15 +193,15 @@ gbp_cmake_pipeline_addin_load (IdeBuildPipelineAddin *addin,
       ide_subprocess_launcher_push_args (configure_launcher, (const gchar * const *)argv);
     }
 
-  configure_stage = ide_build_stage_launcher_new (context, configure_launcher);
-  ide_build_stage_set_name (configure_stage, _("Configure project"));
+  configure_stage = ide_pipeline_stage_launcher_new (context, configure_launcher);
+  ide_pipeline_stage_set_name (configure_stage, _("Configure project"));
 
-  build_ninja = ide_build_pipeline_build_builddir_path (pipeline, "build.ninja", NULL);
+  build_ninja = ide_pipeline_build_builddir_path (pipeline, "build.ninja", NULL);
   if (g_file_test (build_ninja, G_FILE_TEST_IS_REGULAR))
-    ide_build_stage_set_completed (configure_stage, TRUE);
+    ide_pipeline_stage_set_completed (configure_stage, TRUE);
 
-  id = ide_build_pipeline_attach (pipeline, IDE_BUILD_PHASE_CONFIGURE, 0, configure_stage);
-  ide_build_pipeline_addin_track (addin, id);
+  id = ide_pipeline_attach (pipeline, IDE_PIPELINE_PHASE_CONFIGURE, 0, configure_stage);
+  ide_pipeline_addin_track (addin, id);
 
   /* Setup our build stage */
 
@@ -218,35 +218,35 @@ gbp_cmake_pipeline_addin_load (IdeBuildPipelineAddin *addin,
 
   ide_subprocess_launcher_push_argv (clean_launcher, "clean");
 
-  build_stage = ide_build_stage_launcher_new (context, build_launcher);
-  ide_build_stage_set_name (build_stage, _("Building project"));
+  build_stage = ide_pipeline_stage_launcher_new (context, build_launcher);
+  ide_pipeline_stage_set_name (build_stage, _("Building project"));
 
-  ide_build_stage_launcher_set_clean_launcher (IDE_BUILD_STAGE_LAUNCHER (build_stage), clean_launcher);
-  ide_build_stage_set_check_stdout (build_stage, TRUE);
+  ide_pipeline_stage_launcher_set_clean_launcher (IDE_PIPELINE_STAGE_LAUNCHER (build_stage), clean_launcher);
+  ide_pipeline_stage_set_check_stdout (build_stage, TRUE);
 
   g_signal_connect (build_stage,
                     "query",
                     G_CALLBACK (gbp_cmake_pipeline_addin_stage_query_cb),
                     NULL);
 
-  id = ide_build_pipeline_attach (pipeline, IDE_BUILD_PHASE_BUILD, 0, build_stage);
-  ide_build_pipeline_addin_track (addin, id);
+  id = ide_pipeline_attach (pipeline, IDE_PIPELINE_PHASE_BUILD, 0, build_stage);
+  ide_pipeline_addin_track (addin, id);
 
   /* Setup our install stage */
 
   ide_subprocess_launcher_push_argv (install_launcher, ninja);
   ide_subprocess_launcher_push_argv (install_launcher, "install");
 
-  install_stage = ide_build_stage_launcher_new (context, install_launcher);
-  ide_build_stage_set_name (install_stage, _("Installing project"));
+  install_stage = ide_pipeline_stage_launcher_new (context, install_launcher);
+  ide_pipeline_stage_set_name (install_stage, _("Installing project"));
 
   g_signal_connect (install_stage,
                     "query",
                     G_CALLBACK (gbp_cmake_pipeline_addin_stage_query_cb),
                     NULL);
 
-  id = ide_build_pipeline_attach (pipeline, IDE_BUILD_PHASE_INSTALL, 0, install_stage);
-  ide_build_pipeline_addin_track (addin, id);
+  id = ide_pipeline_attach (pipeline, IDE_PIPELINE_PHASE_INSTALL, 0, install_stage);
+  ide_pipeline_addin_track (addin, id);
 
   IDE_EXIT;
 
@@ -256,7 +256,7 @@ failure:
 }
 
 static void
-build_pipeline_addin_iface_init (IdeBuildPipelineAddinInterface *iface)
+pipeline_addin_iface_init (IdePipelineAddinInterface *iface)
 {
   iface->load = gbp_cmake_pipeline_addin_load;
 }
