@@ -14,16 +14,23 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * SPDX-License-Identifier: GPL-3.0-or-later
  */
 
 #define G_LOG_DOMAIN "ide-code-index-search-result"
 
+#include "config.h"
+
+#include <libide-code.h>
+#include <libide-editor.h>
+
 #include "ide-code-index-search-result.h"
 
 struct _IdeCodeIndexSearchResult
 {
-  IdeSearchResult    parent;
-  IdeSourceLocation *location;
+  IdeSearchResult  parent;
+  IdeLocation     *location;
 };
 
 G_DEFINE_TYPE (IdeCodeIndexSearchResult, ide_code_index_search_result, IDE_TYPE_SEARCH_RESULT)
@@ -36,14 +43,23 @@ enum {
 
 static GParamSpec *properties [N_PROPS];
 
-static IdeSourceLocation *
-ide_code_index_search_result_get_source_location (IdeSearchResult *result)
+static void
+ide_code_index_search_result_activate (IdeSearchResult *result,
+                                       GtkWidget       *last_focus)
 {
   IdeCodeIndexSearchResult *self = (IdeCodeIndexSearchResult *)result;
+  IdeWorkspace *workspace;
+  IdeSurface *editor;
 
-  g_return_val_if_fail (IDE_IS_CODE_INDEX_SEARCH_RESULT (self), NULL);
+  g_assert (IDE_IS_CODE_INDEX_SEARCH_RESULT (self));
+  g_assert (GTK_IS_WIDGET (last_focus));
 
-  return ide_source_location_ref (self->location);
+  if (!last_focus)
+    return;
+
+  if ((workspace = ide_widget_get_workspace (last_focus)) &&
+      (editor = ide_workspace_get_surface_by_name (workspace, "editor")))
+    ide_editor_surface_focus_location (IDE_EDITOR_SURFACE (editor), self->location);
 }
 
 static void
@@ -57,7 +73,7 @@ ide_code_index_search_result_get_property (GObject    *object,
   switch (prop_id)
     {
     case PROP_LOCATION:
-      g_value_set_boxed (value, self->location);
+      g_value_set_object (value, self->location);
       break;
 
     default:
@@ -76,7 +92,7 @@ ide_code_index_search_result_set_property (GObject      *object,
   switch (prop_id)
     {
     case PROP_LOCATION:
-      self->location = g_value_dup_boxed (value);
+      self->location = g_value_dup_object (value);
       break;
 
     default:
@@ -89,7 +105,7 @@ ide_code_index_search_result_finalize (GObject *object)
 {
   IdeCodeIndexSearchResult *self = (IdeCodeIndexSearchResult *)object;
 
-  g_clear_pointer (&self->location, ide_source_location_unref);
+  g_clear_object (&self->location);
 
   G_OBJECT_CLASS (ide_code_index_search_result_parent_class)->finalize (object);
 }
@@ -104,14 +120,14 @@ ide_code_index_search_result_class_init (IdeCodeIndexSearchResultClass *klass)
   object_class->set_property = ide_code_index_search_result_set_property;
   object_class->finalize = ide_code_index_search_result_finalize;
 
-  result_class->get_source_location = ide_code_index_search_result_get_source_location;
+  result_class->activate = ide_code_index_search_result_activate;
 
   properties [PROP_LOCATION] =
-    g_param_spec_boxed ("location",
-                        "location",
-                        "Location of symbol.",
-                        IDE_TYPE_SOURCE_LOCATION,
-                        (G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS));
+    g_param_spec_object ("location",
+                         "location",
+                         "Location of symbol.",
+                         IDE_TYPE_LOCATION,
+                         (G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS));
 
   g_object_class_install_properties (object_class, N_PROPS, properties);
 }
@@ -122,11 +138,11 @@ ide_code_index_search_result_init (IdeCodeIndexSearchResult *self)
 }
 
 IdeCodeIndexSearchResult *
-ide_code_index_search_result_new (const gchar       *title,
-                                  const gchar       *subtitle,
-                                  const gchar       *icon_name,
-                                  IdeSourceLocation *location,
-                                  gfloat             score)
+ide_code_index_search_result_new (const gchar *title,
+                                  const gchar *subtitle,
+                                  const gchar *icon_name,
+                                  IdeLocation *location,
+                                  gfloat       score)
 {
   return g_object_new (IDE_TYPE_CODE_INDEX_SEARCH_RESULT,
                        "title", title,
