@@ -45,7 +45,7 @@ typedef struct
 
 typedef struct
 {
-  IdeConfiguration *config;
+  IdeConfig *config;
   gchar            *runtime_id;
   gchar            *name;
   gchar            *arch;
@@ -557,6 +557,9 @@ gbp_flatpak_runtime_provider_bootstrap_cb (GObject      *object,
   g_assert (IDE_IS_TASK (task));
   g_assert (G_IS_ASYNC_RESULT (result));
 
+  if (ide_task_had_error (task))
+    return;
+
   self = ide_task_get_source_object (task);
   state = ide_task_get_task_data (task);
 
@@ -618,7 +621,7 @@ gbp_flatpak_runtime_provider_bootstrap_cb (GObject      *object,
 
 static void
 gbp_flatpak_runtime_provider_bootstrap_async (IdeRuntimeProvider  *provider,
-                                              IdeBuildPipeline    *pipeline,
+                                              IdePipeline    *pipeline,
                                               GCancellable        *cancellable,
                                               GAsyncReadyCallback  callback,
                                               gpointer             user_data)
@@ -629,7 +632,7 @@ gbp_flatpak_runtime_provider_bootstrap_async (IdeRuntimeProvider  *provider,
   g_autofree gchar *branch = NULL;
   g_autoptr(IdeTask) task = NULL;
   g_autoptr(IdeTriplet) triplet = NULL;
-  IdeConfiguration *config;
+  IdeConfig *config;
   IdeToolchain *toolchain;
   BootstrapState *state;
   const gchar *runtime_id;
@@ -638,18 +641,18 @@ gbp_flatpak_runtime_provider_bootstrap_async (IdeRuntimeProvider  *provider,
   IDE_ENTRY;
 
   g_assert (GBP_IS_FLATPAK_RUNTIME_PROVIDER (self));
-  g_assert (IDE_IS_BUILD_PIPELINE (pipeline));
+  g_assert (IDE_IS_PIPELINE (pipeline));
   g_assert (!cancellable || G_IS_CANCELLABLE (cancellable));
 
   task = ide_task_new (self, cancellable, callback, user_data);
   ide_task_set_source_tag (task, gbp_flatpak_runtime_provider_bootstrap_async);
   ide_task_set_priority (task, G_PRIORITY_LOW);
 
-  toolchain = ide_build_pipeline_get_toolchain (pipeline);
+  toolchain = ide_pipeline_get_toolchain (pipeline);
   triplet = ide_toolchain_get_host_triplet (toolchain);
   build_arch = ide_triplet_get_arch (triplet);
-  config = ide_build_pipeline_get_configuration (pipeline);
-  runtime_id = ide_configuration_get_runtime_id (config);
+  config = ide_pipeline_get_config (pipeline);
+  runtime_id = ide_config_get_runtime_id (config);
 
   if (runtime_id == NULL ||
       !g_str_has_prefix (runtime_id, "flatpak:") ||
