@@ -29,7 +29,14 @@ G_BEGIN_DECLS
 
 G_DECLARE_FINAL_TYPE (GbpGitBufferChangeMonitor, gbp_git_buffer_change_monitor, GBP, GIT_BUFFER_CHANGE_MONITOR, IdeBufferChangeMonitor)
 
-void gbp_git_buffer_change_monitor_set_repository (GbpGitBufferChangeMonitor *self,
-                                                   GgitRepository            *repository);
+void     gbp_git_buffer_change_monitor_set_repository (GbpGitBufferChangeMonitor  *self,
+                                                       GgitRepository             *repository);
+void     gbp_git_buffer_change_monitor_wait_async     (GbpGitBufferChangeMonitor  *self,
+                                                       GCancellable               *cancellable,
+                                                       GAsyncReadyCallback         callback,
+                                                       gpointer                    user_data);
+gboolean gbp_git_buffer_change_monitor_wait_finish    (GbpGitBufferChangeMonitor  *self,
+                                                       GAsyncResult               *result,
+                                                       GError                    **error);
 
 G_END_DECLS
