@@ -32,6 +32,8 @@ from gi.repository import Ide
 
 Ide.g_file_add_ignored_pattern('node_modules')
 
+_ = Ide.gettext
+
 class NPMBuildSystemDiscovery(Ide.SimpleBuildSystemDiscovery):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
@@ -52,7 +54,7 @@ class NPMBuildSystem(Ide.Object, Ide.BuildSystem):
         return 100
 
 
-class NPMPipelineAddin(Ide.Object, Ide.BuildPipelineAddin):
+class NPMPipelineAddin(Ide.Object, Ide.PipelineAddin):
     """
     The NPMPipelineAddin is responsible for creating the necessary build
     stages and attaching them to phases of the build pipeline.
@@ -67,7 +69,7 @@ class NPMPipelineAddin(Ide.Object, Ide.BuildPipelineAddin):
             return
 
         package_json = build_system.props.project_file
-        config = pipeline.get_configuration()
+        config = pipeline.get_config()
         builddir = pipeline.get_builddir()
         runtime = config.get_runtime()
 
@@ -85,9 +87,9 @@ class NPMPipelineAddin(Ide.Object, Ide.BuildPipelineAddin):
             fetch_launcher.push_argv('--arch')
             fetch_launcher.push_argv(pipeline.get_host_triplet().get_arch())
         fetch_launcher.push_argv('install')
-        stage = Ide.BuildStageLauncher.new(context, fetch_launcher)
+        stage = Ide.PipelineStageLauncher.new(context, fetch_launcher)
         stage.set_name(_("Downloading npm dependencies"))
-        self.track(pipeline.attach(Ide.BuildPhase.DOWNLOADS, 0, stage))
+        self.track(pipeline.attach(Ide.PipelinePhase.DOWNLOADS, 0, stage))
 
 
 # The scripts used by the npm build system during build
@@ -107,6 +109,9 @@ class NPMBuildTarget(Ide.Object, Ide.BuildTarget):
     def do_get_install_directory(self):
         return None
 
+    def do_get_display_name(self):
+        return 'npm run ' + self._script
+
     def do_get_name(self):
         return 'npm-run-' + self._script
 
@@ -165,13 +170,13 @@ class NPMBuildTargetProvider(Ide.Object, Ide.BuildTargetProvider):
         for name in package_json['scripts']:
             if is_ignored_script(name, package_json['scripts']):
                 continue
-            task.targets.append(NPMBuildTarget(name, context=self.get_context()))
+            task.targets.append(self.ensure_child_typed(NPMBuildTarget(name)))
 
         # if no start script is specified, but server.js exists,
         # we can still run "npm start"
         if 'start' not in package_json['scripts'] and \
             project_file.get_parent().get_child('server.js').query_exists(None):
-                task.targets.append(NPMBuildTarget('start', context=self.get_context()))
+                task.targets.append(self.ensure_child_typed(NPMBuildTarget('start')))
 
         task.return_boolean(True)
 
