@@ -29,6 +29,7 @@
 #include <libide-tree.h>
 #include <libide-vcs.h>
 
+#include "ide-buffer-private.h"
 #include "ide-tree-private.h"
 
 #include "gbp-project-tree-addin.h"
@@ -188,23 +189,12 @@ gbp_project_tree_addin_build_children_async (IdeTreeAddin        *addin,
     {
       IdeContext *context = ide_tree_node_get_item (node);
       g_autoptr(IdeTreeNode) files = NULL;
-      g_autoptr(IdeTreeNode) targets = NULL;
-      //g_autoptr(IdeTreeNode) tests = NULL;
       g_autoptr(IdeProjectFile) root_file = NULL;
       g_autoptr(GFile) workdir = ide_context_ref_workdir (context);
       g_autoptr(GFile) parent = g_file_get_parent (workdir);
       g_autoptr(GFileInfo) info = NULL;
       g_autofree gchar *name = NULL;
 
-#if 0
-      tests = g_object_new (IDE_TYPE_TREE_NODE,
-                            "icon-name", "builder-unit-tests-symbolic",
-                            "item", NULL,
-                            "display-name", _("Unit Tests"),
-                            "children-possible", TRUE,
-                            NULL);
-      ide_tree_node_append (node, tests);
-#endif
 
       info = g_file_info_new ();
       name = g_file_get_basename (workdir);
@@ -724,25 +714,16 @@ gbp_project_tree_addin_transfer_cb (GObject      *object,
     }
   else
     {
+      g_autofree gchar *format = NULL;
       GPtrArray *sources;
-
-      dzl_file_transfer_stat (transfer, &stbuf);
+      gchar count[16];
 
       ide_notification_set_title (notif, _("Files copied"));
 
-      if (stbuf.n_files_total == 1)
-        {
-          ide_notification_set_body (notif, _("Copied 1 file"));
-        }
-      else
-        {
-          g_autofree gchar *format = NULL;
-          gchar count[16];
-
-          g_snprintf (count, sizeof count, "%"G_GINT64_FORMAT, stbuf.n_files_total);
-          format = g_strdup_printf (_("Copied %s files"), count);
-          ide_notification_set_body (notif, format);
-        }
+      dzl_file_transfer_stat (transfer, &stbuf);
+      g_snprintf (count, sizeof count, "%"G_GINT64_FORMAT, stbuf.n_files_total);
+      format = g_strdup_printf (ngettext ("Copied %s file", "Copied %s files", stbuf.n_files_total), count);
+      ide_notification_set_body (notif, format);
 
       sources = g_object_get_data (G_OBJECT (task), "SOURCE_FILES");
 
@@ -783,6 +764,40 @@ gbp_project_tree_addin_transfer_cb (GObject      *object,
   IDE_EXIT;
 }
 
+static void
+gbp_project_tree_addin_rename_buffer_cb (IdeBuffer *buffer,
+                                         gpointer   user_data)
+{
+  struct {
+    GFile *src;
+    GFile *dst;
+  } *foreach = user_data;
+  GFile *file;
+
+  g_assert (IDE_IS_BUFFER (buffer));
+  g_assert (foreach != NULL);
+  g_assert (G_IS_FILE (foreach->src));
+  g_assert (G_IS_FILE (foreach->dst));
+
+  file = ide_buffer_get_file (buffer);
+
+  if (ide_buffer_get_is_temporary (buffer))
+    return;
+
+  if (g_file_has_prefix (file, foreach->src) || g_file_equal (file, foreach->src))
+    {
+      g_autofree gchar *suffix = g_file_get_relative_path (foreach->src, file);
+      g_autoptr(GFile) new_dst = NULL;
+
+      if (suffix == NULL)
+        new_dst = g_file_dup (foreach->dst);
+      else
+        new_dst = g_file_get_child (foreach->dst, suffix);
+
+      _ide_buffer_set_file (buffer, new_dst);
+    }
+}
+
 static void
 gbp_project_tree_addin_node_dropped_async (IdeTreeAddin        *addin,
                                            IdeTreeNode         *drag_node,
@@ -803,6 +818,8 @@ gbp_project_tree_addin_node_dropped_async (IdeTreeAddin        *addin,
   g_auto(GStrv) uris = NULL;
   IdeProjectFile *drag_file;
   IdeProjectFile *drop_file;
+  IdeBufferManager *buffer_manager;
+  IdeContext *context;
 
   IDE_ENTRY;
 
@@ -852,11 +869,18 @@ gbp_project_tree_addin_node_dropped_async (IdeTreeAddin        *addin,
                            notif,
                            0);
 
+  context = ide_object_get_context (IDE_OBJECT (self->model));
+  buffer_manager = ide_buffer_manager_from_context (context);
+
   for (guint i = 0; i < srcs->len; i++)
     {
       GFile *source = g_ptr_array_index (srcs, i);
       g_autofree gchar *name = NULL;
       g_autoptr(GFile) dst_file = NULL;
+      struct {
+        GFile *src;
+        GFile *dst;
+      } foreach;
 
       name = g_file_get_basename (source);
       g_assert (name != NULL);
@@ -871,6 +895,16 @@ gbp_project_tree_addin_node_dropped_async (IdeTreeAddin        *addin,
         }
 
       dzl_file_transfer_add (transfer, source, dst_file);
+
+      /* If there are any buffers that are open with this file as an
+       * ancester, then we need to rename there file to point at the
+       * new location.
+       */
+      foreach.src = source;
+      foreach.dst = dst_file;
+      ide_buffer_manager_foreach (buffer_manager,
+                                  gbp_project_tree_addin_rename_buffer_cb,
+                                  &foreach);
     }
 
   if (actions == GDK_ACTION_MOVE)
